@@ -17,7 +17,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'BINDIR': '/opt/lib/python-3.5.1/bin',
  'BINLIBDEST': '/opt/lib/python-3.5.1/lib/python3.5',
  'BLDLIBRARY': 'libpython3.5m.a',
- 'BLDSHARED': 'gcc -pthread -shared',
+ 'BLDSHARED': 'gcc -pthread -shared -Wl,--version-script=python.map',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'x86_64-unknown-linux-gnu',
@@ -33,11 +33,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFIGURE_CFLAGS': '',
  'CONFIGURE_CFLAGS_NODIST': '-Werror=declaration-after-statement',
  'CONFIGURE_CPPFLAGS': '',
- 'CONFIGURE_LDFLAGS': '',
+ 'CONFIGURE_LDFLAGS': '-Wl,--version-script=python.map',
  'CONFIG_ARGS': "'--prefix=/opt/lib/python-3.5.1' '--enable-ipv6' "
                 "'--enable-loadable-sqlite-extensions' "
                 "'--with-dbmliborder=bdb' '--with-wide-unicode' "
-                "'--with-computed-gotos' '--with-pymalloc'",
+                "'--with-computed-gotos' '--with-pymalloc' "
+                "'LDFLAGS=-Wl,--version-script=python.map'",
  'CONFINCLUDEDIR': '/opt/lib/python-3.5.1/include',
  'CONFINCLUDEPY': '/opt/lib/python-3.5.1/include/python3.5m',
  'COREPYTHONPATH': ':plat-linux',
@@ -475,11 +476,11 @@ build_time_vars = {'ABIFLAGS': 'm',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -pthread -shared',
- 'LDFLAGS': '',
+ 'LDFLAGS': '-Wl,--version-script=python.map',
  'LDLAST': '',
  'LDLIBRARY': 'libpython3.5m.a',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -pthread -shared',
+ 'LDSHARED': 'gcc -pthread -shared -Wl,--version-script=python.map',
  'LDVERSION': '3.5m',
  'LIBC': '',
  'LIBDEST': '/opt/lib/python-3.5.1/lib/python3.5',
@@ -587,7 +588,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PY_CPPFLAGS': '-I. -IInclude -I./Include',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '',
+ 'PY_LDFLAGS': '-Wl,--version-script=python.map',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 0,
  'Py_HASH_ALGORITHM': 0,
