@@ -83,6 +83,20 @@ def float_as_string(f):
 
 
 class InfoStructRNA:
+    __slots__ = (
+        "bl_rna",
+        "identifier",
+        "name",
+        "description",
+        "base",
+        "nested",
+        "full_path",
+        "functions",
+        "children",
+        "references",
+        "properties",
+    )
+
     global_lookup = {}
 
     def __init__(self, rna_type):
@@ -105,8 +119,10 @@ class InfoStructRNA:
     def build(self):
         rna_type = self.bl_rna
         parent_id = self.identifier
-        self.properties[:] = [GetInfoPropertyRNA(rna_prop, parent_id) for rna_prop in get_direct_properties(rna_type) if rna_prop.identifier != "rna_type"]
-        self.functions[:] = [GetInfoFunctionRNA(rna_prop, parent_id) for rna_prop in get_direct_functions(rna_type)]
+        self.properties[:] = [GetInfoPropertyRNA(rna_prop, parent_id)
+                              for rna_prop in get_direct_properties(rna_type) if rna_prop.identifier != "rna_type"]
+        self.functions[:] = [GetInfoFunctionRNA(rna_prop, parent_id)
+                             for rna_prop in get_direct_functions(rna_type)]
 
     def get_bases(self):
         bases = []
@@ -182,6 +198,27 @@ class InfoStructRNA:
 
 
 class InfoPropertyRNA:
+    __slots__ = (
+        "bl_prop",
+        "srna",
+        "identifier",
+        "name",
+        "description",
+        "default_str",
+        "default",
+        "enum_items",
+        "min",
+        "max",
+        "array_length",
+        "collection_type",
+        "type",
+        "fixed_type",
+        "is_argument_optional",
+        "is_enum_flag",
+        "is_required",
+        "is_readonly",
+        "is_never_none",
+    )
     global_lookup = {}
 
     def __init__(self, rna_prop):
@@ -202,6 +239,7 @@ class InfoPropertyRNA:
         self.is_required = rna_prop.is_required
         self.is_readonly = rna_prop.is_readonly
         self.is_never_none = rna_prop.is_never_none
+        self.is_argument_optional = rna_prop.is_argument_optional
 
         self.type = rna_prop.type.lower()
         fixed_type = getattr(rna_prop, "fixed_type", "")
@@ -232,7 +270,8 @@ class InfoPropertyRNA:
             self.default_str = "\"%s\"" % self.default
         elif self.type == "enum":
             if self.is_enum_flag:
-                self.default_str = "%r" % self.default  # repr or set()
+                # self.default_str = "%r" % self.default  # repr or set()
+                self.default_str = "{%s}" % repr(list(sorted(self.default)))[1:-1]
             else:
                 self.default_str = "'%s'" % self.default
         elif self.array_length:
@@ -296,6 +335,8 @@ class InfoPropertyRNA:
         elif as_arg:
             if not self.is_required:
                 type_info.append("optional")
+            if self.is_argument_optional:
+                type_info.append("optional argument")
         else:  # readonly is only useful for self's, not args
             if self.is_readonly:
                 type_info.append("readonly")
@@ -316,6 +357,14 @@ class InfoPropertyRNA:
 
 
 class InfoFunctionRNA:
+    __slots__ = (
+        "bl_func",
+        "identifier",
+        "description",
+        "args",
+        "return_values",
+        "is_classmethod",
+    )
     global_lookup = {}
 
     def __init__(self, rna_func):
@@ -353,6 +402,15 @@ class InfoFunctionRNA:
 
 
 class InfoOperatorRNA:
+    __slots__ = (
+        "bl_op",
+        "identifier",
+        "name",
+        "module_name",
+        "func_name",
+        "description",
+        "args",
+    )
     global_lookup = {}
 
     def __init__(self, rna_op):
@@ -432,6 +490,12 @@ def GetInfoOperatorRNA(bl_rna):
 
 
 def BuildRNAInfo():
+
+    # needed on successive calls to prevent stale data access
+    for cls in (InfoStructRNA, InfoFunctionRNA, InfoOperatorRNA, InfoPropertyRNA):
+        cls.global_lookup.clear()
+    del cls
+
     # Use for faster lookups
     # use rna_struct.identifier as the key for each dict
     rna_struct_dict = {}  # store identifier:rna lookups
@@ -470,7 +534,7 @@ def BuildRNAInfo():
         rna_struct = getattr(rna_type, "bl_rna", None)
 
         if rna_struct:
-            #if not rna_type_name.startswith('__'):
+            # if not rna_type_name.startswith('__'):
 
             identifier = rna_struct.identifier
 
@@ -538,7 +602,8 @@ def BuildRNAInfo():
             for rna_prop_ptr in (getattr(rna_prop, "fixed_type", None), getattr(rna_prop, "srna", None)):
                 # Does this property point to me?
                 if rna_prop_ptr:
-                    rna_references_dict[rna_prop_ptr.identifier].append("%s.%s" % (rna_struct_path, rna_prop_identifier))
+                    rna_references_dict[rna_prop_ptr.identifier].append(
+                        "%s.%s" % (rna_struct_path, rna_prop_identifier))
 
         for rna_func in get_direct_functions(rna_struct):
             for rna_prop_identifier, rna_prop in rna_func.parameters.items():
@@ -550,7 +615,8 @@ def BuildRNAInfo():
 
                 # Does this property point to me?
                 if rna_prop_ptr:
-                    rna_references_dict[rna_prop_ptr.identifier].append("%s.%s" % (rna_struct_path, rna_func.identifier))
+                    rna_references_dict[rna_prop_ptr.identifier].append(
+                        "%s.%s" % (rna_struct_path, rna_func.identifier))
 
         # Store nested children
         nested = rna_struct.nested
@@ -563,8 +629,8 @@ def BuildRNAInfo():
 
     info_structs = []
     for (rna_base, identifier, rna_struct) in structs:
-        #if rna_struct.nested:
-        #    continue
+        # if rna_struct.nested:
+        #     continue
 
         #write_struct(rna_struct, '')
         info_struct = GetInfoStructRNA(rna_struct)
@@ -594,14 +660,16 @@ def BuildRNAInfo():
             for prop in func.return_values:
                 prop.build()
 
-    if 1:
+    # there are too many invalid defaults, unless we intend to fix, leave this off
+    if 0:
         for rna_info in InfoStructRNA.global_lookup.values():
             for prop in rna_info.properties:
                 # ERROR CHECK
                 default = prop.default
                 if type(default) in {float, int}:
                     if default < prop.min or default > prop.max:
-                        print("\t %s.%s, %s not in [%s - %s]" % (rna_info.identifier, prop.identifier, default, prop.min, prop.max))
+                        print("\t %s.%s, %s not in [%s - %s]" %
+                              (rna_info.identifier, prop.identifier, default, prop.min, prop.max))
 
     # now for operators
     op_mods = dir(bpy.ops)
@@ -628,17 +696,17 @@ def BuildRNAInfo():
         for rna_prop in rna_info.args:
             rna_prop.build()
 
-    #for rna_info in InfoStructRNA.global_lookup.values():
-    #    print(rna_info)
+    # for rna_info in InfoStructRNA.global_lookup.values():
+    #     print(rna_info)
     return InfoStructRNA.global_lookup, InfoFunctionRNA.global_lookup, InfoOperatorRNA.global_lookup, InfoPropertyRNA.global_lookup
 
 
-if __name__ == "__main__":
+def main():
     import rna_info
     struct = rna_info.BuildRNAInfo()[0]
     data = []
     for struct_id, v in sorted(struct.items()):
-        struct_id_str = v.identifier  #~ "".join(sid for sid in struct_id if struct_id)
+        struct_id_str = v.identifier  # "".join(sid for sid in struct_id if struct_id)
 
         for base in v.get_bases():
             struct_id_str = base.identifier + "|" + struct_id_str
@@ -651,7 +719,10 @@ if __name__ == "__main__":
             if prop.array_length > 0:
                 prop_type += "[%d]" % prop.array_length
 
-            data.append("%s.%s -> %s:    %s%s    %s" % (struct_id_str, prop.identifier, prop.identifier, prop_type, ", (read-only)" if prop.is_readonly else "", prop.description))
+            data.append(
+                "%s.%s -> %s:    %s%s    %s" %
+                (struct_id_str, prop.identifier, prop.identifier, prop_type,
+                 ", (read-only)" if prop.is_readonly else "", prop.description))
         data.sort()
 
     if bpy.app.background:
@@ -661,3 +732,7 @@ if __name__ == "__main__":
     else:
         text = bpy.data.texts.new(name="api.py")
         text.from_string(data)
+
+
+if __name__ == "__main__":
+    main()
